responses = {
    'accounts': [
        {
            'PrepaidCrypto-P': False,
            'PrepaidCrypto-Z': False,
            'accountAlias': None,
            'accountId': 'DUMMY_ACCOUNT_ID123',
            'accountStatus': 1678852800000,
            'accountTitle': 'Geralt of Rivia',
            'accountVan': 'DUMMY_ACCOUNT_ID123',
            'brokerageAccess': True,
            'businessType': 'INDEPENDENT',
            'clearingStatus': 'O',
            'covestor': False,
            'currency': 'USD',
            'desc': 'DUMMY_ACCOUNT_ID123',
            'displayName': 'Geralt of Rivia',
            'faclient': False,
            'ibEntity': 'IBLLC-US',
            'id': 'DUMMY_ACCOUNT_ID123',
            'noClientTrading': False,
            'parent': {
                'accountId': '',
                'isMChild': False,
                'isMParent': False,
                'isMultiplex': False,
                'mmc': [],
            },
            'trackVirtualFXPortfolio': False,
            'tradingType': 'STKNOPT',
            'type': 'DEMO',
        }
    ],
    'auth_status': {
        'MAC': 'F4:03:43:CD:BD:C0',
        'authenticated': True,
        'competing': False,
        'connected': True,
        'fail': '',
        'hardware_info': '1c4558e8|F4:03:43:CD:BD:C0',
        'message': '',
        'serverInfo': {
            'serverName': 'JifC11113',
            'serverVersion': 'Build 10.25.0m, Nov 17, 2023 11:29:27 AM',
        },
    },
    'conids': {
        'AAPL': 265598,
        'BBVA': 4815,
        'CDN': 453310666,
        'CFC': 42001300,
        'GOOG': 208813720,
        'HUBS': 169544810,
        'META': 107113386,
        'MSFT': 272093,
        'SAN': 12442,
        'SCHW': 11905,
        'TEAM': 589316251,
    },
    'filtered_conids': {
        'AAPL': 532640894,
        'BBVA': 4815,
        'CDN': 453310666,
        'CFC': 42001300,
        'GOOG': 210810667,
        'HUBS': 169544810,
        'META': 114922621,
        'MSFT': 272093,
        'SAN': 12442,
        'SCHW': 11905,
        'TEAM': 589316251,
    },
    'history': {
        'AAPL': {
            'barLength': 2678400,
            'chartAnnotations': 'x/D 0.24/1440;',
            'data': [{'c': 189.37, 'h': 192.93, 'l': 170.12, 'o': 171.05, 't': 1698796800000, 'v': 6942998.04}],
            'high': '19293/6942998.04/1440',
            'low': '17012/6942998.04/1440',
            'mdAvailability': 'S',
            'messageVersion': 2,
            'mktDataDelay': 0,
            'negativeCapable': False,
            'outsideRth': False,
            'points': 0,
            'priceDisplayRule': 1,
            'priceDisplayValue': '2',
            'priceFactor': 100,
            'serverId': '195436',
            'startTime': '20231031-00:00:00',
            'symbol': 'AAPL',
            'text': 'APPLE INC',
            'timePeriod': '1m',
            'travelTime': 3,
            'volumeFactor': 1,
        },
        'BBVA': {
            'barLength': 2678400,
            'data': [{'c': 9.45, 'h': 9.52, 'l': 7.94, 'o': 8.0, 't': 1698796800000, 'v': 211434.01}],
            'high': '952/211434.01/1440',
            'low': '794/211434.01/1440',
            'mdAvailability': 'S',
            'messageVersion': 2,
            'mktDataDelay': 0,
            'negativeCapable': False,
            'outsideRth': False,
            'points': 0,
            'priceDisplayRule': 1,
            'priceDisplayValue': '2',
            'priceFactor': 100,
            'serverId': '195431',
            'startTime': '20231031-00:00:00',
            'symbol': 'BBVA',
            'text': 'BANCO BILBAO VIZCAYA-SP ADR',
            'timePeriod': '1m',
            'travelTime': 2,
            'volumeFactor': 1,
        },
        'CDN': {
            'barLength': 2678400,
            'data': [{'c': 0.32, 'h': 0.37, 'l': 0.26, 'o': 0.37, 't': 1698796800000, 'v': 83773}],
            'high': '74/83773/1440',
            'low': '52/83773/1440',
            'mdAvailability': 'D',
            'messageVersion': 2,
            'mktDataDelay': 900,
            'negativeCapable': False,
            'outsideRth': False,
            'points': 0,
            'priceDisplayRule': 1,
            'priceDisplayValue': '3',
            'priceFactor': 200,
            'serverId': '195417',
            'startTime': '20231031-00:00:00',
            'symbol': 'CDN',
            'text': 'CDN MAVERICK CAPITAL CORP',
            'timePeriod': '1m',
            'travelTime': 3,
            'volumeFactor': 1,
        },
        'CFC': {
            'barLength': 2678400,
            'data': [{'c': 1.62, 'h': 1.91, 'l': 1.48, 'o': 1.63, 't': 1698796800000, 'v': 949972}],
            'high': '3820/949972/1440',
            'low': '2960/949972/1440',
            'mdAvailability': 'D',
            'messageVersion': 2,
            'mktDataDelay': 900,
            'negativeCapable': False,
            'outsideRth': False,
            'points': 0,
            'priceDisplayRule': 1,
            'priceDisplayValue': '4',
            'priceFactor': 2000,
            'serverId': '195419',
            'startTime': '20231031-00:00:00',
            'symbol': 'CFC',
            'text': 'UET UNITED ELECTRONIC TECHNO',
            'timePeriod': '1m',
            'travelTime': 2,
            'volumeFactor': 1,
        },
        'GOOG': {
            'barLength': 2678400,
            'data': [{'c': 136.4, 'h': 141.1, 'l': 124.92, 'o': 125.24, 't': 1698796800000, 'v': 2346378.23}],
            'high': '14110/2346378.23/1440',
            'low': '12492/2346378.23/1440',
            'mdAvailability': 'S',
            'messageVersion': 2,
            'mktDataDelay': 0,
            'negativeCapable': False,
            'outsideRth': False,
            'points': 0,
            'priceDisplayRule': 1,
            'priceDisplayValue': '2',
            'priceFactor': 100,
            'serverId': '195424',
            'startTime': '20231031-00:00:00',
            'symbol': 'GOOG',
            'text': 'ALPHABET INC-CL C',
            'timePeriod': '1m',
            'travelTime': 2,
            'volumeFactor': 1,
        },
        'HUBS': {
            'barLength': 2678400,
            'data': [{'c': 496.52, 'h': 499.15, 'l': 408.62, 'o': 422.06, 't': 1698796800000, 'v': 77847.62}],
            'high': '49915/77847.62/1440',
            'low': '40862/77847.62/1440',
            'mdAvailability': 'S',
            'messageVersion': 2,
            'mktDataDelay': 0,
            'negativeCapable': False,
            'outsideRth': False,
            'points': 0,
            'priceDisplayRule': 1,
            'priceDisplayValue': '2',
            'priceFactor': 100,
            'serverId': '195440',
            'startTime': '20231031-00:00:00',
            'symbol': 'HUBS',
            'text': 'HUBSPOT INC',
            'timePeriod': '1m',
            'travelTime': 3,
            'volumeFactor': 1,
        },
        'META': {
            'barLength': 2678400,
            'data': [{'c': 332.2, 'h': 342.92, 'l': 301.85, 'o': 301.85, 't': 1698796800000, 'v': 1826033.84}],
            'high': '34292/1826033.84/1440',
            'low': '30185/1826033.84/1440',
            'mdAvailability': 'S',
            'messageVersion': 2,
            'mktDataDelay': 0,
            'negativeCapable': False,
            'outsideRth': False,
            'points': 0,
            'priceDisplayRule': 1,
            'priceDisplayValue': '2',
            'priceFactor': 100,
            'serverId': '195438',
            'startTime': '20231031-00:00:00',
            'symbol': 'META',
            'text': 'META PLATFORMS INC-CLASS A',
            'timePeriod': '1m',
            'travelTime': 2,
            'volumeFactor': 1,
        },
        'MSFT': {
            'barLength': 2678400,
            'chartAnnotations': 'x/D 0.75/1440;',
            'data': [{'c': 378.85, 'h': 384.3, 'l': 339.65, 'o': 339.79, 't': 1698796800000, 'v': 2886663.6}],
            'high': '38430/2886663.6/1440',
            'low': '33965/2886663.6/1440',
            'mdAvailability': 'S',
            'messageVersion': 2,
            'mktDataDelay': 0,
            'negativeCapable': False,
            'outsideRth': False,
            'points': 0,
            'priceDisplayRule': 1,
            'priceDisplayValue': '2',
            'priceFactor': 100,
            'serverId': '195433',
            'startTime': '20231031-00:00:00',
            'symbol': 'MSFT',
            'text': 'MICROSOFT CORP',
            'timePeriod': '1m',
            'travelTime': 2,
            'volumeFactor': 1,
        },
        'SAN': {
            'barLength': 2678400,
            'data': [{'c': 4.13, 'h': 4.15, 'l': 3.62, 'o': 3.66, 't': 1698796800000, 'v': 466540.33}],
            'high': '41500/466540.33/1440',
            'low': '36200/466540.33/1440',
            'mdAvailability': 'S',
            'messageVersion': 2,
            'mktDataDelay': 0,
            'negativeCapable': False,
            'outsideRth': False,
            'points': 0,
            'priceDisplayRule': 1,
            'priceDisplayValue': '4',
            'priceFactor': 10000,
            'serverId': '195429',
            'startTime': '20231031-00:00:00',
            'symbol': 'SAN',
            'text': 'BANCO SANTANDER SA-SPON ADR',
            'timePeriod': '1m',
            'travelTime': 3,
            'volumeFactor': 1,
        },
        'SCHW': {
            'barLength': 2678400,
            'chartAnnotations': 'x/D 0.25/1440;',
            'data': [{'c': 59.61, 'h': 59.94, 'l': 51.86, 'o': 52.06, 't': 1698796800000, 'v': 1299913.92}],
            'high': '5994/1299913.92/1440',
            'low': '5186/1299913.92/1440',
            'mdAvailability': 'S',
            'messageVersion': 2,
            'mktDataDelay': 0,
            'negativeCapable': False,
            'outsideRth': False,
            'points': 0,
            'priceDisplayRule': 1,
            'priceDisplayValue': '2',
            'priceFactor': 100,
            'serverId': '195422',
            'startTime': '20231031-00:00:00',
            'symbol': 'SCHW',
            'text': 'SCHWAB (CHARLES) CORP',
            'timePeriod': '1m',
            'travelTime': 2,
            'volumeFactor': 1,
        },
        'TEAM': {
            'barLength': 2678400,
            'data': [{'c': 195.55, 'h': 199.36, 'l': 165.51, 'o': 180.7, 't': 1698796800000, 'v': 171177.85}],
            'high': '19936/171177.85/1440',
            'low': '16551/171177.85/1440',
            'mdAvailability': 'S',
            'messageVersion': 2,
            'mktDataDelay': 0,
            'negativeCapable': False,
            'outsideRth': False,
            'points': 0,
            'priceDisplayRule': 1,
            'priceDisplayValue': '2',
            'priceFactor': 100,
            'serverId': '195426',
            'startTime': '20231031-00:00:00',
            'symbol': 'TEAM',
            'text': 'ATLASSIAN CORP-CL A',
            'timePeriod': '1m',
            'travelTime': 2,
            'volumeFactor': 1,
        },
    },
    'ledger': {
        'BASE': {
            'acctcode': 'DUMMY_ACCOUNT_ID123',
            'cashbalance': 985376.94,
            'cashbalancefxsegment': 0.0,
            'commoditymarketvalue': 0.0,
            'corporatebondsmarketvalue': 0.0,
            'cryptocurrencyvalue': 0.0,
            'currency': 'BASE',
            'dividends': 0.0,
            'exchangerate': 1,
            'funds': 0.0,
            'futuremarketvalue': 0.0,
            'futureoptionmarketvalue': 0.0,
            'futuresonlypnl': 0.0,
            'interest': 3401.28,
            'issueroptionsmarketvalue': 0.0,
            'key': 'LedgerList',
            'moneyfunds': 0.0,
            'netliquidationvalue': 1034222.25,
            'realizedpnl': 0.0,
            'secondkey': 'BASE',
            'sessionid': 1,
            'settledcash': 985376.94,
            'severity': 0,
            'stockmarketvalue': 45444.0,
            'stockoptionmarketvalue': 0.0,
            'tbillsmarketvalue': 0.0,
            'tbondsmarketvalue': 0.0,
            'timestamp': 1701198108,
            'unrealizedpnl': 1701.0,
            'warrantsmarketvalue': 0.0,
        },
        'USD': {
            'acctcode': 'DUMMY_ACCOUNT_ID123',
            'cashbalance': 985376.94,
            'cashbalancefxsegment': 0.0,
            'commoditymarketvalue': 0.0,
            'corporatebondsmarketvalue': 0.0,
            'cryptocurrencyvalue': 0.0,
            'currency': 'USD',
            'dividends': 0.0,
            'endofbundle': 1,
            'exchangerate': 1,
            'funds': 0.0,
            'futuremarketvalue': 0.0,
            'futureoptionmarketvalue': 0.0,
            'futuresonlypnl': 0.0,
            'interest': 3401.28,
            'issueroptionsmarketvalue': 0.0,
            'key': 'LedgerList',
            'moneyfunds': 0.0,
            'netliquidationvalue': 1034222.25,
            'realizedpnl': 0.0,
            'secondkey': 'USD',
            'sessionid': 1,
            'settledcash': 985376.94,
            'severity': 0,
            'stockmarketvalue': 45444.0,
            'stockoptionmarketvalue': 0.0,
            'tbillsmarketvalue': 0.0,
            'tbondsmarketvalue': 0.0,
            'timestamp': 1701198108,
            'unrealizedpnl': 1701.0,
            'warrantsmarketvalue': 0.0,
        },
    },
    'positions': [
        {
            'acctId': 'DUMMY_ACCOUNT_ID123',
            'allExchanges': 'AMEX,NYSE,CBOE,PHLX,CHX,ARCA,ISLAND,ISE,IDEAL,NASDAQQ,DRCTEDGE,BEX,BATS,NITEECN,EDGEA,CSFBALGO,JEFFALGO,PSX,BYX,ITG,PDQ,IBKRATS,CITADEL,NYSEDARK,MIAX,IBDARK,CITADELDP,NASDDARK,IEX,WEDBUSH,SUMMER,WINSLOW,LIQITG,UBSDARK,BTIG,VIRTU,JEFF,OPCO,COWEN,DBK,JPMC,EDGX,JANE,NEEDHAM,FRACSHARE,RBCALGO,VIRTUDP,BAYCREST,FOXRIVER,MND,NITEEXST,PEARL,GSDARK,NITERTL,NYSENAT,IEXMID,HRT,FLOWTRADE,HRTDP,JANELP,PEAK6,IMCDP,CTDLZERO,HRTMID,JANEZERO,HRTEXST,IMCLP,LTSE,SOCGENDP,MEMX,INTELCROS,VIRTUBYIN,JUMPTRADE,NITEZERO,TPLUS1,XTXEXST,XTXDP,XTXMID,COWENLP,BARCDP,JUMPLP,OLDMCLP,RBCCMALP,WALLBETH,IBEOS,JONES,GSLP,BLUEOCEAN,USIBSILP,OVERNIGHT,JANEMID,IBATSEOS,HRTZERO',
            'assetClass': 'STK',
            'avgCost': 437.43,
            'avgPrice': 437.43,
            'chineseName': 'SPDR&#x6807;&#x666E;500 ETF&#x4FE1;&#x6258;',
            'conExchMap': [],
            'conid': 756733,
            'contractDesc': 'SPY',
            'countryCode': 'US',
            'currency': 'USD',
            'displayRule': {
                'displayRuleStep': [{'decimalDigits': 2, 'lowerEdge': 0.0, 'wholeDigits': 4}],
                'magnification': 0,
            },
            'exchs': None,
            'exerciseStyle': None,
            'expiry': None,
            'fullName': 'SPY',
            'group': None,
            'hasOptions': True,
            'incrementRules': [{'increment': 0.01, 'lowerEdge': 0.0}],
            'isEventContract': False,
            'isUS': True,
            'lastTradingDay': None,
            'listingExchange': 'ARCA',
            'mktPrice': 454.44000245,
            'mktValue': 45444.0,
            'model': '',
            'multiplier': 0.0,
            'name': 'SPDR S&P 500 ETF TRUST',
            'pageSize': 100,
            'position': 100.0,
            'putOrCall': None,
            'realizedPnl': 0.0,
            'sector': None,
            'sectorGroup': None,
            'strike': '0',
            'ticker': 'SPY',
            'time': 30,
            'type': 'ETF',
            'undConid': 0,
            'unrealizedPnl': 1701.0,
        }
    ],
    'stocks': {
        'AAPL': [
            {
                'assetClass': 'STK',
                'chineseName': '&#x82F9;&#x679C;&#x516C;&#x53F8;',
                'contracts': [
                    {'conid': 265598, 'exchange': 'NASDAQ', 'isUS': True},
                    {'conid': 38708077, 'exchange': 'MEXI', 'isUS': False},
                    {'conid': 273982664, 'exchange': 'EBS', 'isUS': False},
                ],
                'name': 'APPLE INC',
            },
            {
                'assetClass': 'STK',
                'chineseName': None,
                'contracts': [{'conid': 493546048, 'exchange': 'LSEETF', 'isUS': False}],
                'name': 'LS 1X AAPL',
            },
            {
                'assetClass': 'STK',
                'chineseName': '&#x82F9;&#x679C;&#x516C;&#x53F8;',
                'contracts': [{'conid': 532640894, 'exchange': 'AEQLIT', 'isUS': False}],
                'name': 'APPLE INC-CDR',
            },
        ],
        'BBVA': [
            {
                'assetClass': 'STK',
                'chineseName': '&#x897F;&#x73ED;&#x7259;&#x5BF9;&#x5916;&#x94F6;&#x884C;',
                'contracts': [
                    {'conid': 30314149, 'exchange': 'BM', 'isUS': False},
                    {'conid': 38708792, 'exchange': 'MEXI', 'isUS': False},
                ],
                'name': 'BANCO BILBAO VIZCAYA ARGENTA',
            },
            {
                'assetClass': 'STK',
                'chineseName': '&#x897F;&#x73ED;&#x7259;&#x5BF9;&#x5916;&#x94F6;&#x884C;',
                'contracts': [{'conid': 4815, 'exchange': 'NYSE', 'isUS': True}],
                'name': 'BANCO BILBAO VIZCAYA-SP ADR',
            },
        ],
        'CDN': [
            {
                'assetClass': 'STK',
                'chineseName': None,
                'contracts': [{'conid': 453310666, 'exchange': 'PURE', 'isUS': False}],
                'name': 'CDN MAVERICK CAPITAL CORP',
            }
        ],
        'CFC': [
            {
                'assetClass': 'STK',
                'chineseName': None,
                'contracts': [{'conid': 42001300, 'exchange': 'IBIS', 'isUS': False}],
                'name': 'UET UNITED ELECTRONIC TECHNO',
            }
        ],
        'GOOG': [
            {
                'assetClass': 'STK',
                'chineseName': 'Alphabet&#x516C;&#x53F8;',
                'contracts': [
                    {'conid': 208813720, 'exchange': 'NASDAQ', 'isUS': True},
                    {'conid': 210810667, 'exchange': 'MEXI', 'isUS': False},
                ],
                'name': 'ALPHABET INC-CL C',
            },
            {
                'assetClass': 'STK',
                'chineseName': None,
                'contracts': [{'conid': 493546022, 'exchange': 'LSEETF', 'isUS': False}],
                'name': 'LS 1X GOOG',
            },
            {
                'assetClass': 'STK',
                'chineseName': 'Alphabet&#x516C;&#x53F8;',
                'contracts': [{'conid': 532638805, 'exchange': 'AEQLIT', 'isUS': False}],
                'name': 'ALPHABET INC - CDR',
            },
        ],
        'HUBS': [
            {
                'assetClass': 'STK',
                'chineseName': 'HubSpot&#x516C;&#x53F8;',
                'contracts': [{'conid': 169544810, 'exchange': 'NYSE', 'isUS': True}],
                'name': 'HUBSPOT INC',
            }
        ],
        'META': [
            {
                'assetClass': 'STK',
                'chineseName': 'Meta&#x5E73;&#x53F0;&#x80A1;&#x4EFD;&#x6709;&#x9650;&#x516C;&#x53F8;',
                'contracts': [
                    {'conid': 107113386, 'exchange': 'NASDAQ', 'isUS': True},
                    {'conid': 114922621, 'exchange': 'MEXI', 'isUS': False},
                ],
                'name': 'META PLATFORMS INC-CLASS A',
            },
            {
                'assetClass': 'STK',
                'chineseName': 'WisdomTree&#x5DE5;&#x4E1A;&#x91D1;&#x5C5E;&#x589E;&#x5F3A;',
                'contracts': [
                    {'conid': 355191857, 'exchange': 'LSEETF', 'isUS': False},
                    {'conid': 355194893, 'exchange': 'BVME.ETF', 'isUS': False},
                ],
                'name': 'WT INDUS METALS ENHANCED',
            },
            {
                'assetClass': 'STK',
                'chineseName': 'Meta&#x5E73;&#x53F0;&#x80A1;&#x4EFD;&#x6709;&#x9650;&#x516C;&#x53F8;',
                'contracts': [{'conid': 530091499, 'exchange': 'AEQLIT', 'isUS': False}],
                'name': 'META PLATFORMS INC-CDR',
            },
            {
                'assetClass': 'STK',
                'chineseName': None,
                'contracts': [{'conid': 600541860, 'exchange': 'SFB', 'isUS': False}],
                'name': 'METACON AB',
            },
        ],
        'MSFT': [
            {
                'assetClass': 'STK',
                'chineseName': '&#x5FAE;&#x8F6F;&#x516C;&#x53F8;',
                'contracts': [
                    {'conid': 272093, 'exchange': 'NASDAQ', 'isUS': True},
                    {'conid': 38708990, 'exchange': 'MEXI', 'isUS': False},
                    {'conid': 415569505, 'exchange': 'EBS', 'isUS': False},
                ],
                'name': 'MICROSOFT CORP',
            },
            {
                'assetClass': 'STK',
                'chineseName': None,
                'contracts': [{'conid': 493546075, 'exchange': 'LSEETF', 'isUS': False}],
                'name': 'LS 1X MSFT',
            },
            {
                'assetClass': 'STK',
                'chineseName': '&#x5FAE;&#x8F6F;&#x516C;&#x53F8;',
                'contracts': [{'conid': 518938052, 'exchange': 'AEQLIT', 'isUS': False}],
                'name': 'MICROSOFT CORP-CDR',
            },
        ],
        'SAN': [
            {
                'assetClass': 'STK',
                'chineseName': '&#x6851;&#x5766;&#x5FB7;',
                'contracts': [
                    {'conid': 38708867, 'exchange': 'MEXI', 'isUS': False},
                    {'conid': 385055564, 'exchange': 'WSE', 'isUS': False},
                ],
                'name': 'BANCO SANTANDER SA',
            },
            {
                'assetClass': 'STK',
                'chineseName': '&#x8D5B;&#x8BFA;&#x83F2;',
                'contracts': [{'conid': 29612249, 'exchange': 'SBF', 'isUS': False}],
                'name': 'SANOFI',
            },
            {
                'assetClass': 'STK',
                'chineseName': '&#x6851;&#x5766;&#x5FB7;',
                'contracts': [{'conid': 12442, 'exchange': 'NYSE', 'isUS': True}],
                'name': 'BANCO SANTANDER SA-SPON ADR',
            },
            {
                'assetClass': 'STK',
                'chineseName': '&#x6851;&#x5766;&#x5FB7;&#x82F1;&#x56FD;&#x516C;&#x5171;&#x6709;&#x9650;&#x516C;&#x53F8;',
                'contracts': [{'conid': 80993135, 'exchange': 'LSE', 'isUS': False}],
                'name': 'SANTANDER UK PLC',
            },
            {
                'assetClass': 'STK',
                'chineseName': None,
                'contracts': [{'conid': 199284645, 'exchange': 'ASX', 'isUS': False}],
                'name': 'SAGALIO ENERGY LTD',
            },
            {
                'assetClass': 'STK',
                'chineseName': None,
                'contracts': [{'conid': 221033380, 'exchange': 'VALUE', 'isUS': False}],
                'name': 'CONCORD GREEN ENERGY HOLDINGS',
            },
        ],
        'SCHW': [
            {
                'assetClass': 'STK',
                'chineseName': '&#x5609;&#x4FE1;&#x7406;&#x8D22;',
                'contracts': [
                    {'conid': 11905, 'exchange': 'NYSE', 'isUS': True},
                    {'conid': 174320486, 'exchange': 'MEXI', 'isUS': False},
                ],
                'name': 'SCHWAB (CHARLES) CORP',
            }
        ],
        'TEAM': [
            {
                'assetClass': 'STK',
                'chineseName': 'Team Tankers&#x56FD;&#x9645;&#x6709;&#x9650;&#x516C;&#x53F8;',
                'contracts': [{'conid': 251279169, 'exchange': 'VALUE', 'isUS': False}],
                'name': 'TEAM TANKERS INTERNATIONAL L',
            },
            {
                'assetClass': 'STK',
                'chineseName': None,
                'contracts': [{'conid': 475655801, 'exchange': 'LSE', 'isUS': False}],
                'name': 'TEAM PLC',
            },
            {
                'assetClass': 'STK',
                'chineseName': None,
                'contracts': [{'conid': 589316251, 'exchange': 'NASDAQ', 'isUS': True}],
                'name': 'ATLASSIAN CORP-CL A',
            },
            {
                'assetClass': 'STK',
                'chineseName': None,
                'contracts': [{'conid': 638360210, 'exchange': 'PURE', 'isUS': False}],
                'name': 'CANADIAN NEXUS TEAM VENTURES',
            },
        ],
    },
    'tickle': {
        'collission': False,
        'hmds': {'error': 'no bridge'},
        'iserver': {
            'authStatus': {
                'MAC': 'F4:03:43:CD:BD:C0',
                'authenticated': True,
                'competing': False,
                'connected': True,
                'hardware_info': '1c4558e8|F4:03:43:CD:BD:C0',
                'message': '',
                'serverInfo': {
                    'serverName': 'JifC11113',
                    'serverVersion': 'Build 10.25.0m, Nov 17, 2023 11:29:27 AM',
                },
            }
        },
        'session': 'ce109cbeb462a76dc3f6f4182c830cc1',
        'ssoExpires': 585695,
        'userId': 99996016,
    },
    'live_orders': [
        {
            'account': 'DUMMY_ACCOUNT_ID123',
            'acct': 'DUMMY_ACCOUNT_ID123',
            'bgColor': '#FFFFFF',
            'cashCcy': 'USD',
            'companyName': 'SPDR S&P 500 ETF TRUST',
            'conid': 756733,
            'conidex': '756733',
            'description1': 'SPY',
            'fgColor': '#0000CC',
            'filledQuantity': 0.0,
            'lastExecutionTime': '240103201041',
            'lastExecutionTime_r': 1704312641000,
            'listingExchange': 'ARCA',
            'orderDesc': 'Buy 1 Limit 457.00, GTC',
            'orderId': 1210386759,
            'orderType': 'Limit',
            'order_ccp_status': 'Submitted',
            'order_ref': '240103-SPY-1-BUY-L@457-bxv8',
            'origOrderType': 'LIMIT',
            'outsideRTH': False,
            'price': '457.00',
            'remainingQuantity': 1.0,
            'secType': 'STK',
            'side': 'BUY',
            'sizeAndFills': '0/1',
            'status': 'PreSubmitted',
            'supportsTaxOpt': '1',
            'ticker': 'SPY',
            'timeInForce': 'GTC',
            'totalSize': 1.0,
        },
        {
            'account': 'DUMMY_ACCOUNT_ID123',
            'acct': 'DUMMY_ACCOUNT_ID123',
            'bgColor': '#FFFFFF',
            'cashCcy': 'USD',
            'companyName': 'SPDR S&P 500 ETF TRUST',
            'conid': 756733,
            'conidex': '756733',
            'description1': 'SPY',
            'fgColor': '#0000CC',
            'filledQuantity': 0.0,
            'lastExecutionTime': '240103200639',
            'lastExecutionTime_r': 1704312399000,
            'listingExchange': 'ARCA',
            'orderDesc': 'Buy 1 Limit 457.00, GTC',
            'orderId': 1210386726,
            'orderType': 'Limit',
            'order_ccp_status': 'Submitted',
            'order_ref': '240103-SPY-1-BUY-L@457-pfqd',
            'origOrderType': 'LIMIT',
            'outsideRTH': False,
            'price': '457.00',
            'remainingQuantity': 1.0,
            'secType': 'STK',
            'side': 'BUY',
            'sizeAndFills': '0/1',
            'status': 'PreSubmitted',
            'supportsTaxOpt': '1',
            'ticker': 'SPY',
            'timeInForce': 'GTC',
            'totalSize': 1.0,
        },
        {
            'account': 'DUMMY_ACCOUNT_ID123',
            'acct': 'DUMMY_ACCOUNT_ID123',
            'bgColor': '#FFFFFF',
            'cashCcy': 'USD',
            'companyName': 'SPDR S&P 500 ETF TRUST',
            'conid': 756733,
            'conidex': '756733',
            'description1': 'SPY',
            'fgColor': '#0000CC',
            'filledQuantity': 0.0,
            'lastExecutionTime': '240103010227',
            'lastExecutionTime_r': 1704243747000,
            'listingExchange': 'ARCA',
            'orderDesc': 'Buy 1 Limit 453.00, GTC',
            'orderId': 1928088808,
            'orderType': 'Limit',
            'order_ccp_status': 'Submitted',
            'order_ref': '240103-SPY-1-BUY-L@453-v5DU',
            'origOrderType': 'LIMIT',
            'outsideRTH': False,
            'price': '453.00',
            'remainingQuantity': 1.0,
            'secType': 'STK',
            'side': 'BUY',
            'sizeAndFills': '0/1',
            'status': 'PreSubmitted',
            'supportsTaxOpt': '1',
            'ticker': 'SPY',
            'timeInForce': 'GTC',
            'totalSize': 1.0,
        },
        {
            'account': 'DUMMY_ACCOUNT_ID123',
            'acct': 'DUMMY_ACCOUNT_ID123',
            'bgColor': '#FFFFFF',
            'cashCcy': 'USD',
            'companyName': 'SPDR S&P 500 ETF TRUST',
            'conid': 756733,
            'conidex': '756733',
            'description1': 'SPY',
            'fgColor': '#0000CC',
            'filledQuantity': 0.0,
            'lastExecutionTime': '240103212831',
            'lastExecutionTime_r': 1704317311000,
            'listingExchange': 'ARCA',
            'orderDesc': 'Buy 1 Limit 458.00, GTC',
            'orderId': 1210387040,
            'orderType': 'Limit',
            'order_ccp_status': 'Submitted',
            'order_ref': '240103-SPY-1-BUY-L@458-J5cN',
            'origOrderType': 'LIMIT',
            'outsideRTH': False,
            'price': '458.00',
            'remainingQuantity': 1.0,
            'secType': 'STK',
            'side': 'BUY',
            'sizeAndFills': '0/1',
            'status': 'PreSubmitted',
            'supportsTaxOpt': '1',
            'ticker': 'SPY',
            'timeInForce': 'GTC',
            'totalSize': 1.0,
        },
    ],
    'order_status': {
        '1210386759': {
            'account': 'DUMMY_ACCOUNT_ID123',
            'alert_active': 1,
            'allowed_duplicate_opposite': True,
            'available_chart_periods': '#R|1',
            'bg_color': '#0000CC',
            'cannot_cancel_order': False,
            'child_order_type': '3',
            'company_name': 'SPDR S&P 500 ETF TRUST',
            'conid': 756733,
            'conidex': '756733',
            'contract_description_1': 'SPY',
            'cum_fill': '0.0',
            'currency': 'USD',
            'deactivate_order': False,
            'editable_fields': '\x1e',
            'exit_strategy_chart_description': 'Buy 1 Limit 457.00, GTC',
            'exit_strategy_display_price': '457.00',
            'exit_strategy_tool_availability': '1',
            'fg_color': '#FFFFFF',
            'limit_price': '457.00',
            'listing_exchange': 'ARCA',
            'option_acct': 'c',
            'order_ccp_status': '0',
            'order_clearing_account': 'DUMMY_ACCOUNT_ID123',
            'order_description': 'Buy 1 Limit 457.00, GTC',
            'order_description_with_contract': 'Buy 1 SPY Limit 457.00, GTC',
            'order_id': 1210386759,
            'order_not_editable': False,
            'order_status': 'PreSubmitted',
            'order_status_description': 'Order Submitted',
            'order_time': '240103201041',
            'order_type': 'LIMIT',
            'outside_rth': False,
            'request_id': '37888',
            'sec_type': 'STK',
            'server_id': '0',
            'side': 'B',
            'size': '1.0',
            'size_and_fills': '0/1',
            'sub_type': None,
            'symbol': 'SPY',
            'tif': 'GTC',
            'total_size': '1.0',
            'use_price_mgmt_algo': False,
        },
        '1210386726': {
            'account': 'DUMMY_ACCOUNT_ID123',
            'alert_active': 1,
            'allowed_duplicate_opposite': True,
            'available_chart_periods': '#R|1',
            'bg_color': '#0000CC',
            'cannot_cancel_order': False,
            'child_order_type': '3',
            'company_name': 'SPDR S&P 500 ETF TRUST',
            'conid': 756733,
            'conidex': '756733',
            'contract_description_1': 'SPY',
            'cum_fill': '0.0',
            'currency': 'USD',
            'deactivate_order': False,
            'editable_fields': '\x1e',
            'exit_strategy_chart_description': 'Buy 1 Limit 457.00, GTC',
            'exit_strategy_display_price': '457.00',
            'exit_strategy_tool_availability': '1',
            'fg_color': '#FFFFFF',
            'limit_price': '457.00',
            'listing_exchange': 'ARCA',
            'option_acct': 'c',
            'order_ccp_status': '0',
            'order_clearing_account': 'DUMMY_ACCOUNT_ID123',
            'order_description': 'Buy 1 Limit 457.00, GTC',
            'order_description_with_contract': 'Buy 1 SPY Limit 457.00, GTC',
            'order_id': 1210386726,
            'order_not_editable': False,
            'order_status': 'PreSubmitted',
            'order_status_description': 'Order Submitted',
            'order_time': '240103200639',
            'order_type': 'LIMIT',
            'outside_rth': False,
            'request_id': '37889',
            'sec_type': 'STK',
            'server_id': '1',
            'side': 'B',
            'size': '1.0',
            'size_and_fills': '0/1',
            'sub_type': None,
            'symbol': 'SPY',
            'tif': 'GTC',
            'total_size': '1.0',
            'use_price_mgmt_algo': False,
        },
        '1928088808': {
            'account': 'DUMMY_ACCOUNT_ID123',
            'alert_active': 1,
            'allowed_duplicate_opposite': True,
            'available_chart_periods': '#R|1',
            'bg_color': '#0000CC',
            'cannot_cancel_order': False,
            'child_order_type': '3',
            'company_name': 'SPDR S&P 500 ETF TRUST',
            'conid': 756733,
            'conidex': '756733',
            'contract_description_1': 'SPY',
            'cum_fill': '0.0',
            'currency': 'USD',
            'deactivate_order': False,
            'editable_fields': '\x1e',
            'exit_strategy_chart_description': 'Buy 1 Limit 453.00, GTC',
            'exit_strategy_display_price': '453.00',
            'exit_strategy_tool_availability': '1',
            'fg_color': '#FFFFFF',
            'limit_price': '453.00',
            'listing_exchange': 'ARCA',
            'option_acct': 'c',
            'order_ccp_status': '0',
            'order_clearing_account': 'DUMMY_ACCOUNT_ID123',
            'order_description': 'Buy 1 Limit 453.00, GTC',
            'order_description_with_contract': 'Buy 1 SPY Limit 453.00, GTC',
            'order_id': 1928088808,
            'order_not_editable': False,
            'order_status': 'PreSubmitted',
            'order_status_description': 'Order Submitted',
            'order_time': '240103010227',
            'order_type': 'LIMIT',
            'outside_rth': False,
            'request_id': '37890',
            'sec_type': 'STK',
            'server_id': '2',
            'side': 'B',
            'size': '1.0',
            'size_and_fills': '0/1',
            'sub_type': None,
            'symbol': 'SPY',
            'tif': 'GTC',
            'total_size': '1.0',
            'use_price_mgmt_algo': False,
        },
        '1210386714': {
            'account': 'DUMMY_ACCOUNT_ID123',
            'alert_active': 1,
            'allowed_duplicate_opposite': True,
            'available_chart_periods': '#R|1',
            'bg_color': '#00F000',
            'cannot_cancel_order': False,
            'child_order_type': '3',
            'company_name': 'SPDR S&P 500 ETF TRUST',
            'conid': 756733,
            'conidex': '756733',
            'contract_description_1': 'SPY',
            'cum_fill': '0.0',
            'currency': 'USD',
            'deactivate_order': False,
            'editable_fields': '\x1e',
            'exit_strategy_chart_description': 'Buy 1 Limit 457.00, GTC',
            'exit_strategy_display_price': '457.00',
            'exit_strategy_tool_availability': '1',
            'fg_color': '#000000',
            'limit_price': '457.00',
            'listing_exchange': 'ARCA',
            'option_acct': 'c',
            'order_ccp_status': '0',
            'order_clearing_account': 'DUMMY_ACCOUNT_ID123',
            'order_description': 'Buy 1 Limit 457.00, GTC',
            'order_description_with_contract': 'Buy 1 SPY Limit 457.00, GTC',
            'order_id': 1210386714,
            'order_not_editable': False,
            'order_status': 'Submitted',
            'order_status_description': 'Order Submitted',
            'order_time': '240103200503',
            'order_type': 'LIMIT',
            'outside_rth': False,
            'request_id': '216243',
            'sec_type': 'STK',
            'server_id': '824',
            'side': 'B',
            'size': '1.0',
            'size_and_fills': '0/1',
            'sub_type': None,
            'symbol': 'SPY',
            'tif': 'GTC',
            'total_size': '1.0',
            'use_price_mgmt_algo': False,
        },
    },
}
